==> db4o_6.1.401~dfsg.orig.tar.gz: db4o-6.1/src/Db4objects.Db4o.Tests/Db4objects.Db4o.Tests/Common/Fieldindex/AllTests.cs <==
/* Copyright (C) 2004 - 2006  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace Db4objects.Db4o.Tests.Common.Fieldindex
{
	public class AllTests : Db4oUnit.Extensions.Db4oTestSuite
	{
		public static void Main(string[] args)
		{
			new Db4objects.Db4o.Tests.Common.Fieldindex.AllTests().RunSolo();
		}

		protected override System.Type[] TestCases()
		{
			System.Type[] fieldBased = { typeof(Db4objects.Db4o.Tests.Common.Fieldindex.IndexedNodeTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Fieldindex.FieldIndexTestCase), typeof(Db4objects.Db4o.Tests.Common.Fieldindex.FieldIndexProcessorTestCase)
				 };
			System.Type[] neutral = { typeof(Db4objects.Db4o.Tests.Common.Fieldindex.DoubleFieldIndexTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Fieldindex.StringIndexTestCase), typeof(Db4objects.Db4o.Tests.Common.Fieldindex.StringIndexCorruptionTestCase)
				 };
			System.Type[] tests = neutral;
			tests = new System.Type[fieldBased.Length + neutral.Length];
			System.Array.Copy(neutral, 0, tests, 0, neutral.Length);
			System.Array.Copy(fieldBased, 0, tests, neutral.Length, fieldBased.Length);
			return tests;
		}
	}
}

==> db4o_6.1.604+dfsg.orig.tar.gz: db4o-6.1.604/src/Db4objects.Db4o.Tests/Db4objects.Db4o.Tests/Common/Fieldindex/AllTests.cs <==
/* Copyright (C) 2004 - 2007  db4objects Inc.  http://www.db4o.com

This file is part of the db4o open source object database.

db4o is free software; you can redistribute it and/or modify it under
the terms of version 2 of the GNU General Public License as published
by the Free Software Foundation and as clarified by db4objects' GPL 
interpretation policy, available at
http://www.db4o.com/about/company/legalpolicies/gplinterpretation/
Alternatively you can write to db4objects, Inc., 1900 S Norfolk Street,
Suite 350, San Mateo, CA 94403, USA.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. */
namespace Db4objects.Db4o.Tests.Common.Fieldindex
{
	public class AllTests : Db4oUnit.Extensions.Db4oTestSuite
	{
		public static void Main(string[] args)
		{
			new Db4objects.Db4o.Tests.Common.Fieldindex.AllTests().RunSolo();
		}

		protected override System.Type[] TestCases()
		{
			System.Type[] fieldBased = { typeof(Db4objects.Db4o.Tests.Common.Fieldindex.IndexedNodeTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Fieldindex.FieldIndexTestCase), typeof(Db4objects.Db4o.Tests.Common.Fieldindex.FieldIndexProcessorTestCase)
				 };
			System.Type[] neutral = { typeof(Db4objects.Db4o.Tests.Common.Fieldindex.DoubleFieldIndexTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Fieldindex.RuntimeFieldIndexTestCase), typeof(Db4objects.Db4o.Tests.Common.Fieldindex.StringIndexTestCase)
				, typeof(Db4objects.Db4o.Tests.Common.Fieldindex.StringIndexCorruptionTestCase) };
			System.Type[] tests = neutral;
			tests = new System.Type[fieldBased.Length + neutral.Length];
			System.Array.Copy(neutral, 0, tests, 0, neutral.Length);
			System.Array.Copy(fieldBased, 0, tests, neutral.Length, fieldBased.Length);
			return tests;
		}
	}
}
